@@ -2,8 +2,10 @@ const pyodideWorker = new Worker("./{{ name }}.js");
 pyodideWorker.busy = false
 pyodideWorker.queue = []
 
+let patching = 0
+
 function send_change(jsdoc, event) {
-  if (event.setter_id != null && event.setter_id == 'py') {
+  if ((event.setter_id != null && event.setter_id == 'py') || (patching > 0)) {
     return
   } else if (pyodideWorker.busy && event.model && event.attr) {
     let events = []
@@ -82,6 +84,11 @@ pyodideWorker.onmessage = async (event) => {
     pyodideWorker.postMessage({'type': 'rendered'})
     pyodideWorker.postMessage({'type': 'location', location: JSON.stringify(window.location)})
   } else if (msg.type === 'patch') {
-    pyodideWorker.jsdoc.apply_json_patch(msg.patch, msg.buffers, setter_id='py')
+    try {
+      patching += 1
+      pyodideWorker.jsdoc.apply_json_patch(msg.patch, msg.buffers)
+    } finally {
+      patching -= 1
+    }
   }
 };
