@@ -20,7 +20,7 @@ from functools import partial, wraps
 from html import escape
 from types import FunctionType, MethodType
 from typing import (
-    TYPE_CHECKING, Any, Callable, Dict, Mapping, Optional, Union,
+    TYPE_CHECKING, Any, Callable, Mapping, Optional, Union,
 )
 from urllib.parse import urljoin, urlparse
 
@@ -276,7 +276,7 @@ def server_html_page_for_session(
     title: str,
     token: str | None = None,
     template: str | Template = BASE_TEMPLATE,
-    template_variables: Optional[Dict[str, Any]] = None,
+    template_variables: Optional[dict[str, Any]] = None,
 ) -> str:
 
     # ALERT: Replace with better approach before Bokeh 3.x compatible release
@@ -579,7 +579,7 @@ class AutoloadJsHandler(BkAutoloadJsHandler, SessionPrefixHandler):
         absolute_url = self.get_argument("bokeh-absolute-url", default=None)
 
         if absolute_url:
-            server_url = '{uri.scheme}://{uri.netloc}'.format(uri=urlparse(absolute_url))
+            server_url = f'{urlparse(absolute_url).scheme}://{urlparse(absolute_url).netloc}'
         else:
             server_url = None
 
