@@ -1,32 +1,35 @@
 import {div} from "@bokehjs/core/dom"
 import {isArray} from "@bokehjs/core/util/types"
 import {WidgetView} from "@bokehjs/models/widgets/widget"
-import {Markup} from "@bokehjs/models/widgets/markup"
+import type {Markup} from "@bokehjs/models/widgets/markup"
 import {LayoutDOM, LayoutDOMView} from "@bokehjs/models/layouts/layout_dom"
-import * as p from "@bokehjs/core/properties"
+import type * as p from "@bokehjs/core/properties"
 
 export class PanelMarkupView extends WidgetView {
+  declare model: Markup
+
   container: HTMLDivElement
-  model: Markup
   _initialized_stylesheets: any
 
-  connect_signals(): void {
+  override connect_signals(): void {
     super.connect_signals()
-    const {width, height, min_height, max_height, margin, sizing_mode} = this.model.properties;
+    const {width, height, min_height, max_height, margin, sizing_mode} = this.model.properties
     this.on_change([width, height, min_height, max_height, margin, sizing_mode], () => {
       set_size(this.el, this.model)
       set_size(this.container, this.model, false)
-    });
+    })
   }
 
   override async lazy_initialize() {
     await super.lazy_initialize()
 
-    if (this.provider.status == "not_started" || this.provider.status == "loading")
+    if (this.provider.status == "not_started" || this.provider.status == "loading") {
       this.provider.ready.connect(() => {
-        if (this.contains_tex_string(this.model.text))
+        if (this.contains_tex_string(this.model.text)) {
           this.render()
+        }
       })
+    }
   }
 
   watch_stylesheets(): void {
@@ -34,16 +37,18 @@ export class PanelMarkupView extends WidgetView {
     for (const sts of this._applied_stylesheets) {
       const style_el = (sts as any).el
       if (style_el instanceof HTMLLinkElement) {
-	this._initialized_stylesheets[style_el.href] = false
-	style_el.addEventListener("load", () => {
-	  this._initialized_stylesheets[style_el.href] = true
-	  if (
-	    Object.values(this._initialized_stylesheets).every(Boolean)
-	  )
-	    this.style_redraw()
-	})
+        this._initialized_stylesheets[style_el.href] = false
+        style_el.addEventListener("load", () => {
+          this._initialized_stylesheets[style_el.href] = true
+          if (Object.values(this._initialized_stylesheets).every(Boolean)) {
+            this.style_redraw()
+          }
+        })
       }
     }
+    if (Object.keys(this._initialized_stylesheets).length === 0) {
+      this.style_redraw()
+    }
   }
 
   style_redraw(): void {
@@ -60,8 +65,9 @@ export class PanelMarkupView extends WidgetView {
     set_size(this.container, this.model, false)
     this.shadow_el.appendChild(this.container)
 
-    if (this.provider.status == "failed" || this.provider.status == "loaded")
+    if (this.provider.status == "failed" || this.provider.status == "loaded") {
       this._has_finished = true
+    }
   }
 }
 
@@ -70,30 +76,30 @@ export function set_size(el: HTMLElement, model: HTMLBox, adjustMargin: boolean
   let height_policy = model.height != null ? "fixed" : "fit"
   const {sizing_mode, margin} = model
   if (sizing_mode != null) {
-    if (sizing_mode == "fixed")
+    if (sizing_mode == "fixed") {
       width_policy = height_policy = "fixed"
-    else if (sizing_mode == "stretch_both")
+    } else if (sizing_mode == "stretch_both") {
       width_policy = height_policy = "max"
-    else if (sizing_mode == "stretch_width")
+    } else if (sizing_mode == "stretch_width") {
       width_policy = "max"
-    else if (sizing_mode == "stretch_height")
+    } else if (sizing_mode == "stretch_height") {
       height_policy = "max"
-    else {
+    } else {
       switch (sizing_mode) {
-      case "scale_width":
-        width_policy = "max"
-        height_policy = "min"
-        break
-      case "scale_height":
-        width_policy = "min"
-        height_policy = "max"
-        break
-      case "scale_both":
-        width_policy = "max"
-        height_policy = "max"
-        break
-      default:
-        throw new Error("unreachable")
+        case "scale_width":
+          width_policy = "max"
+          height_policy = "min"
+          break
+        case "scale_height":
+          width_policy = "min"
+          height_policy = "max"
+          break
+        case "scale_both":
+          width_policy = "max"
+          height_policy = "max"
+          break
+        default:
+          throw new Error("unreachable")
       }
     }
   }
@@ -113,37 +119,44 @@ export function set_size(el: HTMLElement, model: HTMLBox, adjustMargin: boolean
   } else {
     wm = hm = margin * 2
   }
-  if (width_policy == "fixed" && model.width)
-    el.style.width = model.width + "px";
-  else if (width_policy == "max")
-    el.style.width = wm ? `calc(100% - ${wm}px)`: "100%";
-  if (model.min_width != null)
-    el.style.minWidth = model.min_width + "px";
-  if (model.max_width != null)
-    el.style.maxWidth = model.max_width + "px";
-  if (height_policy == "fixed" && model.height)
-    el.style.height = model.height + "px";
-  else if (height_policy == "max")
-    el.style.height = hm ? `calc(100% - ${hm}px)`: "100%";
-  if (model.min_height != null)
-    el.style.minHeight = model.min_height + "px";
-  if (model.max_width != null)
-    el.style.maxHeight = model.max_height + "px";
+  if (width_policy == "fixed" && model.width) {
+    el.style.width = `${model.width}px`
+  } else if (width_policy == "max") {
+    el.style.width = wm ? `calc(100% - ${wm}px)`: "100%"
+  }
+  if (model.min_width != null) {
+    el.style.minWidth = `${model.min_width}px`
+  }
+  if (model.max_width != null) {
+    el.style.maxWidth = `${model.max_width}px`
+  }
+  if (height_policy == "fixed" && model.height) {
+    el.style.height = `${model.height}px`
+  } else if (height_policy == "max") {
+    el.style.height = hm ? `calc(100% - ${hm}px)`: "100%"
+  }
+  if (model.min_height != null) {
+    el.style.minHeight = `${model.min_height}px`
+  }
+  if (model.max_width != null) {
+    el.style.maxHeight = `${model.max_height}px`
+  }
 }
 
 export abstract class HTMLBoxView extends LayoutDOMView {
-  override model: HTMLBox
+  declare model: HTMLBox
+
   _initialized_stylesheets: any
 
-  connect_signals(): void {
+  override connect_signals(): void {
     super.connect_signals()
-    const {width, height, min_height, max_height, margin, sizing_mode} = this.model.properties;
+    const {width, height, min_height, max_height, margin, sizing_mode} = this.model.properties
     this.on_change([width, height, min_height, max_height, margin, sizing_mode], () => {
       set_size(this.el, this.model)
-    });
+    })
   }
 
-  render(): void {
+  override render(): void {
     super.render()
     set_size(this.el, this.model)
   }
@@ -153,14 +166,13 @@ export abstract class HTMLBoxView extends LayoutDOMView {
     for (const sts of this._applied_stylesheets) {
       const style_el = (sts as any).el
       if (style_el instanceof HTMLLinkElement) {
-	this._initialized_stylesheets[style_el.href] = false
-	style_el.addEventListener("load", () => {
-	  this._initialized_stylesheets[style_el.href] = true
-	  if (
-	    Object.values(this._initialized_stylesheets).every(Boolean)
-	  )
-	    this.style_redraw()
-	})
+        this._initialized_stylesheets[style_el.href] = false
+        style_el.addEventListener("load", () => {
+          this._initialized_stylesheets[style_el.href] = true
+          if (Object.values(this._initialized_stylesheets).every(Boolean)) {
+            this.style_redraw()
+          }
+        })
       }
     }
   }
@@ -181,7 +193,7 @@ export namespace HTMLBox {
 export interface HTMLBox extends HTMLBox.Attrs {}
 
 export abstract class HTMLBox extends LayoutDOM {
-  override properties: HTMLBox.Props
+  declare properties: HTMLBox.Props
 
   constructor(attrs?: Partial<HTMLBox.Attrs>) {
     super(attrs)
