@@ -6,17 +6,27 @@ from bokeh.core.properties import (
     Any, Bool, Either, Enum, Float, Instance, Int, List, Nullable, Override,
     String, Tuple,
 )
+from bokeh.events import ModelEvent
 from bokeh.models.ui import Tooltip
 from bokeh.models.ui.icons import Icon
 from bokeh.models.widgets import (
     Button as bkButton, CheckboxButtonGroup as bkCheckboxButtonGroup,
-    InputWidget, RadioButtonGroup as bkRadioButtonGroup, Select,
+    InputWidget, MultiSelect, RadioButtonGroup as bkRadioButtonGroup, Select,
     TextAreaInput as BkTextAreaInput, Widget,
 )
 
 from .layout import HTMLBox
 
 
+class DoubleClickEvent(ModelEvent):
+
+    event_name = 'dblclick_event'
+
+    def __init__(self, model, option=None):
+        self.option = option
+        super().__init__(model=model)
+
+
 class Player(Widget):
     """
     The Player widget provides controls to play through a number of frames.
@@ -193,6 +203,11 @@ class CustomSelect(Select):
     size = Int(default=1)
 
 
+class CustomMultiSelect(MultiSelect):
+    """
+    MultiSelect widget which allows capturing double tap events.
+    """
+
 class TooltipIcon(Widget):
     description = Instance(
         Tooltip,
