@@ -8,7 +8,7 @@ import re
 import sys
 
 from typing import (
-    TYPE_CHECKING, Any, ClassVar, Dict, List, Mapping, Type,
+    TYPE_CHECKING, Any, ClassVar, Mapping,
 )
 
 import param  # type: ignore
@@ -65,7 +65,7 @@ class LaTeX(ModelPane):
 
     _updates: ClassVar[bool] = True
 
-    _stylesheets: ClassVar[List[str]] = [
+    _stylesheets: ClassVar[list[str]] = [
         f'{CDN_DIST}css/katex.css'
     ]
 
@@ -78,14 +78,14 @@ class LaTeX(ModelPane):
         else:
             return False
 
-    def _process_param_change(self, params) -> Dict[str, Any]:
+    def _process_param_change(self, params) -> dict[str, Any]:
         if self.renderer == "mathjax":
             # Replace $$math$$ with \[math\] and $math$ with \(math\)
             msg = re.sub(r"(\$\$)(.*?)(\$\$)", r"\[\2\]", params["object"])
             params["object"] = re.sub(r"(\$)(.*?)(\$)", r"\(\2\)", msg)
         return super()._process_param_change(params)
 
-    def _get_model_type(self, root: Model, comm: Comm | None) -> Type[Model]:
+    def _get_model_type(self, root: Model, comm: Comm | None) -> type[Model]:
         module = self.renderer
         if module is None:
             if 'panel.models.mathjax' in sys.modules and 'panel.models.katex' not in sys.modules:
@@ -105,7 +105,7 @@ class LaTeX(ModelPane):
         self._models[root.ref['id']] = (model, parent)
         return model
 
-    def _transform_object(self, obj: Any) -> Dict[str, Any]:
+    def _transform_object(self, obj: Any) -> dict[str, Any]:
         if obj is None:
             obj = ''
         elif hasattr(obj, '_repr_latex_'):
