@@ -2,18 +2,20 @@ import os
 
 from pathlib import Path
 
+import bokeh
+
 from packaging.version import Version
 
 from panel.config import config, panel_extension as extension
-from panel.io.convert import BOKEH_VERSION
 from panel.io.resources import (
-    CDN_DIST, DIST_DIR, PANEL_DIR, Resources, resolve_custom_path,
-    set_resource_mode,
+    CDN_DIST, DIST_DIR, JS_VERSION, PANEL_DIR, Resources, resolve_custom_path,
+    resolve_stylesheet, set_resource_mode,
 )
 from panel.io.state import set_curdoc
+from panel.theme.native import Native
 from panel.widgets import Button
 
-bokeh_version = Version(BOKEH_VERSION)
+bokeh_version = Version(bokeh.__version__)
 if bokeh_version.is_devrelease or bokeh_version.is_prerelease:
     bk_prefix = 'dev'
 else:
@@ -41,11 +43,11 @@ def test_resources_cdn():
     resources = Resources(mode='cdn', minified=True)
     assert resources.js_raw == ['Bokeh.set_log_level("info");']
     assert resources.js_files == [
-        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-{BOKEH_VERSION}.min.js',
-        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-gl-{BOKEH_VERSION}.min.js',
-        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-widgets-{BOKEH_VERSION}.min.js',
-        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-tables-{BOKEH_VERSION}.min.js',
-        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-mathjax-{BOKEH_VERSION}.min.js',
+        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-{bokeh_version}.min.js',
+        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-gl-{bokeh_version}.min.js',
+        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-widgets-{bokeh_version}.min.js',
+        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-tables-{bokeh_version}.min.js',
+        f'https://cdn.bokeh.org/bokeh/{bk_prefix}/bokeh-mathjax-{bokeh_version}.min.js',
     ]
 
 def test_resources_server_absolute():
@@ -86,7 +88,7 @@ def test_resources_model_server(document):
                 'static/extensions/panel/bundled/datatabulator/luxon/build/global/luxon.min.js',
             ]
             assert resources.css_files == [
-                'static/extensions/panel/bundled/datatabulator/tabulator-tables@5.5.0/dist/css/tabulator_simple.min.css'
+                f'static/extensions/panel/bundled/datatabulator/tabulator-tables@5.5.0/dist/css/tabulator_simple.min.css?v={JS_VERSION}'
             ]
 
 def test_resources_model_cdn(document):
@@ -99,7 +101,7 @@ def test_resources_model_cdn(document):
                 f'{CDN_DIST}bundled/datatabulator/luxon/build/global/luxon.min.js',
             ]
             assert resources.css_files == [
-                f'{CDN_DIST}bundled/datatabulator/tabulator-tables@5.5.0/dist/css/tabulator_simple.min.css'
+                f'{CDN_DIST}bundled/datatabulator/tabulator-tables@5.5.0/dist/css/tabulator_simple.min.css?v={JS_VERSION}'
             ]
 
 def test_resources_model_inline(document):
@@ -124,8 +126,8 @@ def test_resources_reactive_html_server(document):
                 'static/extensions/panel/bundled/gridstack/gridstack@7.2.3/dist/gridstack-all.js'
             ]
             assert resources.css_files == [
-                'static/extensions/panel/bundled/gridstack/gridstack@7.2.3/dist/gridstack.min.css',
-                'static/extensions/panel/bundled/gridstack/gridstack@7.2.3/dist/gridstack-extra.min.css'
+                f'static/extensions/panel/bundled/gridstack/gridstack@7.2.3/dist/gridstack.min.css?v={JS_VERSION}',
+                f'static/extensions/panel/bundled/gridstack/gridstack@7.2.3/dist/gridstack-extra.min.css?v={JS_VERSION}'
             ]
 
 def test_resources_reactive_html_cdn(document):
@@ -137,8 +139,8 @@ def test_resources_reactive_html_cdn(document):
                 f'{CDN_DIST}bundled/gridstack/gridstack@7.2.3/dist/gridstack-all.js'
             ]
             assert resources.css_files == [
-                f'{CDN_DIST}bundled/gridstack/gridstack@7.2.3/dist/gridstack.min.css',
-                f'{CDN_DIST}bundled/gridstack/gridstack@7.2.3/dist/gridstack-extra.min.css'
+                f'{CDN_DIST}bundled/gridstack/gridstack@7.2.3/dist/gridstack.min.css?v={JS_VERSION}',
+                f'{CDN_DIST}bundled/gridstack/gridstack@7.2.3/dist/gridstack-extra.min.css?v={JS_VERSION}'
             ]
 
 def test_resources_reactive_html_inline(document):
@@ -180,3 +182,27 @@ def test_resources_design_inline(document):
             assert resources.js_raw[-1:] == [
                 (DIST_DIR / 'bundled/bootstrap5/js/bootstrap.bundle.min.js').read_text(encoding='utf-8')
             ]
+
+def test_resolve_stylesheet_long_css():
+    cls = Native
+    stylesheet="""
+.styled-button {
+    display: inline-block;
+    padding: 10px 20px;
+    font-size: 16px;
+    font-weight: bold;
+    text-align: center;
+    text-decoration: none;
+    background-color: #4CAF50;
+    color: white;
+    border: none;
+    border-radius: 5px;
+    cursor: pointer;
+    transition: background-color 0.3s;
+}
+
+.styled-button:hover {
+    background-color: #45a049;
+}
+"""
+    assert resolve_stylesheet(cls, stylesheet, "_stylesheets")==stylesheet
