@@ -9,7 +9,7 @@ import pytest
 from requests.exceptions import MissingSchema
 
 from panel.pane import (
-    GIF, ICO, JPG, PDF, PNG, SVG,
+    GIF, ICO, JPG, PDF, PNG, SVG, WebP,
 )
 from panel.pane.markup import escape
 
@@ -17,7 +17,7 @@ JPG_FILE = 'https://assets.holoviz.org/panel/samples/jpg_sample.jpg'
 JPEG_FILE = 'https://assets.holoviz.org/panel/samples/jpeg_sample.jpeg'
 PNG_FILE = 'https://assets.holoviz.org/panel/samples/png_sample.png'
 SVG_FILE = 'https://assets.holoviz.org/panel/samples/svg_sample.svg'
-
+WEBP_FILE = 'https://assets.holoviz.org/panel/samples/webp_sample.webp'
 
 def test_jpeg_applies():
     assert JPG.applies(JPEG_FILE)
@@ -69,14 +69,17 @@ twopixel = dict(\
           b'AAAAAAAAAAAAAAAAFBv/EABkRAAEFAAAAAAAAAAAAAAAAAAEAAjFxsf/aAAwDAQ' + \
           b'ACEQMRAD8AA0qs5HvTHQcJdsChioXSbOr/2Q==',
     ico = b'AAABAAEAAgEAAAEAIAA0AAAAFgAAACgAAAACAAAAAgAAAAEAIAAAAAAACAAAAHQ' + \
-          b'SAAB0EgAAAAAAAAAAAAD//////////wAAAAA=')
+          b'SAAB0EgAAAAAAAAAAAAD//////////wAAAAA=',
+    webp= b'UklGRkIAAABXRUJQVlA4WAoAAAAQAAAAAQAAAAAAQUxQSAMAAAAAAAAAVlA4IBg' + \
+          b'AAAAwAQCdASoCAAEAAUAmJaQAA3AA/v02aAA='
+          )
 
 
-def test_imgshape():
-    for t in [PNG, JPG, GIF, ICO]:
-        w,h = t._imgshape(b64decode(twopixel[t.name.lower()]))
-        assert w == 2
-        assert h == 1
+@pytest.mark.parametrize('t', [PNG, JPG, GIF, ICO, WebP], ids=lambda t: t.name.lower())
+def test_imgshape(t):
+    w, h = t._imgshape(b64decode(twopixel[t.name.lower()]))
+    assert w == 2
+    assert h == 1
 
 def test_load_from_byteio():
     """Testing a loading a image from a ByteIo"""
