@@ -14,10 +14,8 @@ from bokeh.events import ButtonClick
 
 from panel.config import config
 from panel.io import state
-from panel.io.resources import DIST_DIR
-from panel.io.server import (
-    INDEX_HTML, get_server, serve, set_curdoc,
-)
+from panel.io.resources import DIST_DIR, JS_VERSION
+from panel.io.server import INDEX_HTML, get_server, set_curdoc
 from panel.layout import Row
 from panel.models import HTML as BkHTML
 from panel.models.tabulator import TableEditEvent
@@ -105,7 +103,7 @@ def test_server_template_static_resources_with_prefix_relative_url():
 
     r = serve_and_request({'template': template}, prefix='/prefix', suffix="/prefix/template")
 
-    assert 'href="static/extensions/panel/bundled/bootstraptemplate/bootstrap.css"' in r.content.decode('utf-8')
+    assert f'href="static/extensions/panel/bundled/bootstraptemplate/bootstrap.css?v={JS_VERSION}"' in r.content.decode('utf-8')
 
 
 def test_server_template_static_resources_with_subpath_and_prefix_relative_url():
@@ -113,7 +111,7 @@ def test_server_template_static_resources_with_subpath_and_prefix_relative_url()
 
     r = serve_and_request({'/subpath/template': template}, prefix='/prefix', suffix="/prefix/subpath/template")
 
-    assert 'href="../static/extensions/panel/bundled/bootstraptemplate/bootstrap.css"' in r.content.decode('utf-8')
+    assert f'href="../static/extensions/panel/bundled/bootstraptemplate/bootstrap.css?v={JS_VERSION}"' in r.content.decode('utf-8')
 
 
 def test_server_extensions_on_root():
@@ -178,11 +176,14 @@ def test_server_async_local_state(bokeh_curdoc):
 
 def test_server_async_local_state_nested_tasks(bokeh_curdoc):
     docs = {}
+    _tasks = set()
 
     async def task(depth=1):
         await asyncio.sleep(0.5)
         if depth > 0:
-            asyncio.ensure_future(task(depth-1))
+            _task = asyncio.ensure_future(task(depth-1))
+            _tasks.add(_task)
+            _task.add_done_callback(_tasks.discard)
         docs[state.curdoc] = []
         for _ in range(10):
             await asyncio.sleep(0.1)
@@ -280,7 +281,7 @@ def test_server_session_info():
     assert state.session_info['live'] == 0
 
 
-def test_server_periodic_async_callback(threads, port):
+def test_server_periodic_async_callback(threads):
     counts = []
 
     async def cb(count=[0]):
@@ -290,6 +291,9 @@ def test_server_periodic_async_callback(threads, port):
     def app():
         button = Button(name='Click')
         state.add_periodic_callback(cb, 100)
+        def loaded():
+            state._schedule_on_load(state.curdoc, None)
+        state.execute(loaded, schedule=True)
         return button
 
     serve_and_request(app)
@@ -495,18 +499,15 @@ def test_serve_can_serve_bokeh_app_from_file():
     assert "/bk-app" in server._tornado.applications
 
 
-def test_server_on_load_after_init(threads, port):
+
+def test_server_on_load_after_init_with_threads(threads):
     loaded = []
 
     def cb():
-        loaded.append(state.loaded)
-
-    def cb2():
-        state.execute(cb, schedule=True)
+        loaded.append((state.curdoc, state.loaded))
 
     def app():
         state.onload(cb)
-        state.onload(cb2)
         # Simulate rendering
         def loaded():
             state._schedule_on_load(state.curdoc, None)
@@ -515,11 +516,43 @@ def test_server_on_load_after_init(threads, port):
 
     serve_and_request(app)
 
-    # Checks whether onload callback was executed twice once before and once after load
-    wait_until(lambda: loaded == [False, True])
+    wait_until(lambda: len(loaded) == 1)
+
+    doc = loaded[0][0]
+    with set_curdoc(doc):
+        state.onload(cb)
+
+    wait_until(lambda: len(loaded) == 2)
+    assert loaded == [(doc, False), (doc, True)]
 
 
-def test_server_on_load_during_load(threads, port):
+def test_server_on_load_after_init():
+    loaded = []
+
+    def cb():
+        loaded.append((state.curdoc, state.loaded))
+
+    def app():
+        state.onload(cb)
+        # Simulate rendering
+        def loaded():
+            state._schedule_on_load(state.curdoc, None)
+        state.execute(loaded, schedule=True)
+        return 'App'
+
+    serve_and_request(app)
+
+    wait_until(lambda: len(loaded) == 1)
+
+    doc = loaded[0][0]
+    with set_curdoc(doc):
+        state.onload(cb)
+
+    wait_until(lambda: len(loaded) == 2)
+    assert loaded == [(doc, False), (doc, True)]
+
+
+def test_server_on_load_during_load(threads):
     loaded = []
 
     def cb():
@@ -543,7 +576,7 @@ def test_server_on_load_during_load(threads, port):
     wait_until(lambda: loaded == [False, False])
 
 
-def test_server_thread_pool_on_load(threads, port):
+def test_server_thread_pool_on_load(threads):
     counts = []
 
     def cb(count=[0]):
@@ -569,7 +602,7 @@ def test_server_thread_pool_on_load(threads, port):
     wait_until(lambda: len(counts) > 0 and max(counts) > 1)
 
 
-def test_server_thread_pool_execute(threads, port):
+def test_server_thread_pool_execute(threads):
     counts = []
 
     def cb(count=[0]):
@@ -589,7 +622,7 @@ def test_server_thread_pool_execute(threads, port):
     wait_until(lambda: len(counts) > 0 and max(counts) > 1)
 
 
-def test_server_thread_pool_defer_load(threads, port):
+def test_server_thread_pool_defer_load(threads):
     counts = []
 
     def cb(count=[0]):
@@ -617,7 +650,7 @@ def test_server_thread_pool_defer_load(threads, port):
     wait_until(lambda: len(counts) > 0 and max(counts) > 1)
 
 
-def test_server_thread_pool_change_event(threads, port):
+def test_server_thread_pool_change_event(threads):
     button = Button(name='Click')
     button2 = Button(name='Click')
 
@@ -645,7 +678,7 @@ def test_server_thread_pool_change_event(threads, port):
     wait_until(lambda: len(counts) > 0 and max(counts) > 1)
 
 
-def test_server_thread_pool_bokeh_event(threads, port):
+def test_server_thread_pool_bokeh_event(threads):
     import pandas as pd
 
     df = pd.DataFrame([[1, 1], [2, 2]], columns=['A', 'B'])
@@ -673,7 +706,7 @@ def test_server_thread_pool_bokeh_event(threads, port):
     wait_until(lambda: len(counts) > 0 and max(counts) > 1)
 
 
-def test_server_thread_pool_periodic(threads, port):
+def test_server_thread_pool_periodic(threads):
     counts = []
 
     def cb(count=[0]):
@@ -685,6 +718,9 @@ def test_server_thread_pool_periodic(threads, port):
     def app():
         button = Button(name='Click')
         state.add_periodic_callback(cb, 100)
+        def loaded():
+            state._schedule_on_load(state.curdoc, None)
+        state.execute(loaded, schedule=True)
         return button
 
     serve_and_request(app)
@@ -693,7 +729,7 @@ def test_server_thread_pool_periodic(threads, port):
     wait_until(lambda: len(counts) > 0 and max(counts) > 1)
 
 
-def test_server_thread_pool_onload(threads, port):
+def test_server_thread_pool_onload(threads):
     counts = []
 
     def app(count=[0]):
@@ -719,7 +755,7 @@ def test_server_thread_pool_onload(threads, port):
     wait_until(lambda: len(counts) > 0 and max(counts) > 1)
 
 
-def test_server_thread_pool_busy(threads, port):
+def test_server_thread_pool_busy(threads):
     button = Button(name='Click')
 
     def cb(event):
@@ -741,7 +777,7 @@ def test_server_thread_pool_busy(threads, port):
     wait_until(lambda: state._busy_counter == 0 and not state.busy)
 
 
-def test_server_async_onload(threads, port):
+def test_server_async_onload(threads):
     counts = []
 
     def app(count=[0]):
@@ -839,7 +875,7 @@ def test_server_component_custom_resources_with_prefix_relative_url(port):
 
     r = serve_and_request({'component': component}, prefix='/prefix', suffix='/prefix/component')
 
-    assert 'href="components/panel.tests.test_server/CustomComponent/__css__/assets/custom.css"' in r.content.decode('utf-8')
+    assert f'href="components/panel.tests.test_server/CustomComponent/__css__/assets/custom.css?v={JS_VERSION}"' in r.content.decode('utf-8')
 
 
 def test_server_component_custom_resources_with_subpath_and_prefix_relative_url(port):
@@ -847,7 +883,7 @@ def test_server_component_custom_resources_with_subpath_and_prefix_relative_url(
 
     r = serve_and_request({'/subpath/component': component}, prefix='/prefix', suffix='/prefix/subpath/component')
 
-    assert 'href="../components/panel.tests.test_server/CustomComponent/__css__/assets/custom.css"' in r.content.decode('utf-8')
+    assert f'href="../components/panel.tests.test_server/CustomComponent/__css__/assets/custom.css?v={JS_VERSION}"' in r.content.decode('utf-8')
 
 
 def test_server_component_css_with_prefix_relative_url(port):
@@ -879,7 +915,7 @@ async def async_handler(event=None):
         ('threads', async_handler),
         ('nothreads', async_handler)
 ])
-def test_server_exception_handler_bokeh_event(threads, handler, port, request):
+def test_server_exception_handler_bokeh_event(threads, handler, request):
     request.getfixturevalue(threads)
 
     exceptions = []
@@ -910,7 +946,7 @@ def test_server_exception_handler_bokeh_event(threads, handler, port, request):
         ('threads', async_handler),
         ('nothreads', async_handler)
 ])
-def test_server_exception_handler_async_change_event(threads, handler, port, request):
+def test_server_exception_handler_async_change_event(threads, handler, request):
     request.getfixturevalue(threads)
 
     exceptions = []
@@ -941,7 +977,7 @@ def test_server_exception_handler_async_change_event(threads, handler, port, req
         ('threads', async_handler),
         ('nothreads', async_handler)
 ])
-def test_server_exception_handler_async_onload_event(threads, handler, port, request):
+def test_server_exception_handler_async_onload_event(threads, handler, request):
     request.getfixturevalue(threads)
 
     exceptions = []
@@ -965,7 +1001,7 @@ def test_server_exception_handler_async_onload_event(threads, handler, port, req
     wait_until(lambda: len(exceptions) == 1)
 
 
-def test_server_no_warning_empty_layout(port, caplog):
+def test_server_no_warning_empty_layout(caplog):
 
     bk_logger = logging.getLogger('bokeh')
     old_level = bk_logger.level
@@ -977,11 +1013,8 @@ def test_server_no_warning_empty_layout(port, caplog):
 
         app = Row()
 
-        serve(app, port=port, threaded=True, show=False)
+        serve_and_request(app)
 
-        # Wait for server to start
-        time.sleep(1)
-        requests.get(f"http://localhost:{port}")
         time.sleep(1)
 
         for rec in caplog.records:
@@ -992,7 +1025,7 @@ def test_server_no_warning_empty_layout(port, caplog):
         bk_logger.propagate = old_propagate
 
 
-def test_server_threads_save(threads, port, tmp_path):
+def test_server_threads_save(threads, tmp_path):
     # https://github.com/holoviz/panel/issues/5957
 
     button = Button()
