@@ -5,8 +5,7 @@ events or merely toggling between on-off states.
 from __future__ import annotations
 
 from typing import (
-    TYPE_CHECKING, Any, Awaitable, Callable, ClassVar, Dict, List, Mapping,
-    Optional, Type,
+    TYPE_CHECKING, Any, Awaitable, Callable, ClassVar, Mapping, Optional,
 )
 
 import param
@@ -29,8 +28,8 @@ if TYPE_CHECKING:
     from ..links import JSLinkTarget, Link
 
 
-BUTTON_TYPES: List[str] = ['default', 'primary', 'success', 'warning', 'danger', 'light']
-BUTTON_STYLES: List[str] = ['solid', 'outline']
+BUTTON_TYPES: list[str] = ['default', 'primary', 'success', 'warning', 'danger', 'light']
+BUTTON_STYLES: list[str] = ['solid', 'outline']
 
 class _ButtonBase(Widget):
 
@@ -46,7 +45,7 @@ class _ButtonBase(Widget):
 
     _source_transforms: ClassVar[Mapping[str, str | None]] = {'button_style': None}
 
-    _stylesheets: ClassVar[List[str]] = [f'{CDN_DIST}css/button.css']
+    _stylesheets: ClassVar[list[str]] = [f'{CDN_DIST}css/button.css']
 
     __abstract = True
 
@@ -103,7 +102,7 @@ class _ClickButton(Widget):
         self._register_events(self._event, model=model, doc=doc, comm=comm)
         return model
 
-    def js_on_click(self, args: Dict[str, Any] = {}, code: str = "") -> Callback:
+    def js_on_click(self, args: dict[str, Any] = {}, code: str = "") -> Callback:
         """
         Allows defining a JS callback to be triggered when the button
         is clicked.
@@ -123,7 +122,7 @@ class _ClickButton(Widget):
         from ..links import Callback
         return Callback(self, code={'event:'+self._event: code}, args=args)
 
-    def jscallback(self, args: Dict[str, Any] = {}, **callbacks: str) -> Callback:
+    def jscallback(self, args: dict[str, Any] = {}, **callbacks: str) -> Callback:
         """
         Allows defining a Javascript (JS) callback to be triggered when a property
         changes on the source object. The keyword arguments define the
@@ -188,7 +187,7 @@ class Button(_ButtonBase, _ClickButton, IconMixin, TooltipMixin):
         'event:button_click': None, 'value': None,
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkButton
+    _widget_type: ClassVar[type[Model]] = _BkButton
 
     def __init__(self, **params):
         click_handler = params.pop('on_click', None)
@@ -197,12 +196,12 @@ class Button(_ButtonBase, _ClickButton, IconMixin, TooltipMixin):
             self.on_click(click_handler)
 
     @property
-    def _linkable_params(self) -> List[str]:
+    def _linkable_params(self) -> list[str]:
         return super()._linkable_params + ['value']
 
     def jslink(
-        self, target: JSLinkTarget, code: Optional[Dict[str, str]] = None,
-        args: Optional[Dict[str, Any]] = None, bidirectional: bool = False,
+        self, target: JSLinkTarget, code: Optional[dict[str, str]] = None,
+        args: Optional[dict[str, Any]] = None, bidirectional: bool = False,
         **links: str
     ) -> Link:
         """
@@ -293,7 +292,7 @@ class Toggle(_ButtonBase, IconMixin):
 
     _supports_embed: ClassVar[bool] = True
 
-    _widget_type: ClassVar[Type[Model]] = _BkToggle
+    _widget_type: ClassVar[type[Model]] = _BkToggle
 
     def _get_embed_state(self, root, values=None, max_opts=3):
         return (self, self._models[root.ref['id']][0], [False, True],
@@ -332,7 +331,7 @@ class MenuButton(_ButtonBase, _ClickButton, IconMixin):
 
     _rename: ClassVar[Mapping[str, str | None]] = {'name': 'label', 'items': 'menu', 'clicked': None}
 
-    _widget_type: ClassVar[Type[Model]] = _BkDropdown
+    _widget_type: ClassVar[type[Model]] = _BkDropdown
 
     def __init__(self, **params):
         click_handler = params.pop('on_click', None)
