@@ -10,8 +10,7 @@ import json
 from base64 import b64decode
 from datetime import date, datetime
 from typing import (
-    TYPE_CHECKING, Any, ClassVar, Dict, Iterable, Mapping, Optional, Tuple,
-    Type,
+    TYPE_CHECKING, Any, ClassVar, Iterable, Mapping, Optional,
 )
 
 import numpy as np
@@ -72,7 +71,7 @@ class TextInput(Widget):
       Width of this component. If sizing_mode is set to stretch
       or scale mode this will merely be used as a suggestion.""")
 
-    _widget_type: ClassVar[Type[Model]] = _BkTextInput
+    _widget_type: ClassVar[type[Model]] = _BkTextInput
 
     @classmethod
     def from_param(cls, parameter: param.Parameter, onkeyup=False, **params) -> Viewable:
@@ -111,7 +110,7 @@ class PasswordInput(TextInput):
     ... )
     """
 
-    _widget_type: ClassVar[Type[Model]] = _BkPasswordInput
+    _widget_type: ClassVar[type[Model]] = _BkPasswordInput
 
 
 class TextAreaInput(TextInput):
@@ -149,7 +148,7 @@ class TextAreaInput(TextInput):
         and if so in which dimensions: `width`, `height`, or `both`.
         Can only be set during initialization.""")
 
-    _widget_type: ClassVar[Type[Model]] = _bkTextAreaInput
+    _widget_type: ClassVar[type[Model]] = _bkTextAreaInput
 
 
 class FileInput(Widget):
@@ -193,7 +192,7 @@ class FileInput(Widget):
         'value': "'data:' + source.mime_type + ';base64,' + value"
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkFileInput
+    _widget_type: ClassVar[type[Model]] = _BkFileInput
 
     def _process_param_change(self, msg):
         msg = super()._process_param_change(msg)
@@ -279,7 +278,7 @@ class StaticText(Widget):
         'value': 'value.split(": ")[1]'
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkDiv
+    _widget_type: ClassVar[type[Model]] = _BkDiv
 
     def _process_param_change(self, msg):
         msg = super()._process_param_change(msg)
@@ -334,7 +333,7 @@ class DatePicker(Widget):
         'start': 'min_date', 'end': 'max_date'
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkDatePicker
+    _widget_type: ClassVar[type[Model]] = _BkDatePicker
 
     def __init__(self, **params):
         # Since options is the standard for other widgets,
@@ -405,7 +404,7 @@ class DateRangePicker(Widget):
         'start': 'min_date', 'end': 'max_date'
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkDateRangePicker
+    _widget_type: ClassVar[type[Model]] = _BkDateRangePicker
 
     def __init__(self, **params):
         super().__init__(**params)
@@ -487,7 +486,7 @@ class _DatetimePickerBase(Widget):
         'start': 'min_date', 'end': 'max_date', 'as_numpy_datetime64': None,
     }
 
-    _widget_type: ClassVar[Type[Model]] = _bkDatetimePicker
+    _widget_type: ClassVar[type[Model]] = _bkDatetimePicker
 
     __abstract = True
 
@@ -651,7 +650,7 @@ class ColorPicker(Widget):
       Width of this component. If sizing_mode is set to stretch
       or scale mode this will merely be used as a suggestion.""")
 
-    _widget_type: ClassVar[Type[Model]] = _BkColorPicker
+    _widget_type: ClassVar[type[Model]] = _BkColorPicker
 
     _rename: ClassVar[Mapping[str, str | None]] = {'value': 'color'}
 
@@ -678,7 +677,7 @@ class _NumericInputBase(Widget):
 
     _rename: ClassVar[Mapping[str, str | None]] = {'start': 'low', 'end': 'high'}
 
-    _widget_type: ClassVar[Type[Model]] = _BkNumericInput
+    _widget_type: ClassVar[type[Model]] = _BkNumericInput
 
     __abstract = True
 
@@ -733,7 +732,7 @@ class _SpinnerBase(_NumericInputBase):
 
     _rename: ClassVar[Mapping[str, str | None]] = {'value_throttled': None}
 
-    _widget_type: ClassVar[Type[Model]] = _BkSpinner
+    _widget_type: ClassVar[type[Model]] = _BkSpinner
 
     __abstract = True
 
@@ -751,11 +750,11 @@ class _SpinnerBase(_NumericInputBase):
                                         params=', '.join(param_reprs(self, ['value_throttled'])))
 
     @property
-    def _linked_properties(self) -> Tuple[str]:
+    def _linked_properties(self) -> tuple[str]:
         return super()._linked_properties + ('value_throttled',)
 
     def _update_model(
-        self, events: Dict[str, param.parameterized.Event], msg: Dict[str, Any],
+        self, events: dict[str, param.parameterized.Event], msg: dict[str, Any],
         root: Model, model: Model, doc: Document, comm: Optional[Comm]
     ) -> None:
         if 'value_throttled' in msg:
@@ -910,7 +909,7 @@ class LiteralInput(Widget):
         'value': """JSON.stringify(value).replace(/,/g, ",").replace(/:/g, ": ")"""
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkTextInput
+    _widget_type: ClassVar[type[Model]] = _BkTextInput
 
     def __init__(self, **params):
         super().__init__(**params)
@@ -925,9 +924,8 @@ class LiteralInput(Widget):
             if event:
                 self.value = event.old
             types = repr(self.type) if isinstance(self.type, tuple) else self.type.__name__
-            raise ValueError('LiteralInput expected %s type but value %s '
-                             'is of type %s.' %
-                             (types, new, type(new).__name__))
+            raise ValueError(f'LiteralInput expected {types} type but value {new} '
+                             f'is of type {type(new).__name__}.')
 
     def _process_property_change(self, msg):
         msg = super()._process_property_change(msg)
@@ -1105,9 +1103,8 @@ class DatetimeInput(LiteralInput):
             end = datetime.strftime(self.end, self.format)
             if event:
                 self.value = event.old
-            raise ValueError('DatetimeInput value must be between {start} and {end}, '
-                             'supplied value is {value}'.format(start=start, end=end,
-                                                                value=value))
+            raise ValueError(f'DatetimeInput value must be between {start} and {end}, '
+                             f'supplied value is {value}')
 
     def _process_property_change(self, msg):
         msg = Widget._process_property_change(self, msg)
@@ -1170,7 +1167,7 @@ class DatetimeRangeInput(CompositeWidget):
     format = param.String(default='%Y-%m-%d %H:%M:%S', doc="""
         Datetime format used for parsing and formatting the datetime.""")
 
-    _composite_type: ClassVar[Type[Panel]] = Column
+    _composite_type: ClassVar[type[Panel]] = Column
 
     def __init__(self, **params):
         self._text = StaticText(margin=(5, 0, 0, 0), styles={'white-space': 'nowrap'})
@@ -1256,7 +1253,7 @@ class Checkbox(_BooleanWidget):
     >>> Checkbox(name='Works with the tools you know and love', value=True)
     """
 
-    _widget_type: ClassVar[Type[Model]] = _BkCheckbox
+    _widget_type: ClassVar[type[Model]] = _BkCheckbox
 
 
 class Switch(_BooleanWidget):
@@ -1277,4 +1274,4 @@ class Switch(_BooleanWidget):
         'name': None, 'value': 'active'
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkSwitch
+    _widget_type: ClassVar[type[Model]] = _BkSwitch
