@@ -10,7 +10,7 @@ from __future__ import annotations
 import datetime as dt
 
 from typing import (
-    TYPE_CHECKING, Any, ClassVar, Dict, List, Mapping, Optional, Tuple, Type,
+    TYPE_CHECKING, Any, ClassVar, Mapping, Optional,
 )
 
 import numpy as np
@@ -67,7 +67,7 @@ class _SliderBase(Widget):
     tooltips = param.Boolean(default=True, doc="""
         Whether the slider handle should display tooltips.""")
 
-    _widget_type: ClassVar[Type[Model]] = _BkSlider
+    _widget_type: ClassVar[type[Model]] = _BkSlider
 
     __abstract = True
 
@@ -83,7 +83,7 @@ class _SliderBase(Widget):
                                         params=', '.join(param_reprs(self, ['value_throttled'])))
 
     @property
-    def _linked_properties(self) -> Tuple[str]:
+    def _linked_properties(self) -> tuple[str]:
         return super()._linked_properties + ('value_throttled',)
 
     def _process_property_change(self, msg):
@@ -95,7 +95,7 @@ class _SliderBase(Widget):
         return super()._process_property_change(msg)
 
     def _update_model(
-        self, events: Dict[str, param.parameterized.Event], msg: Dict[str, Any],
+        self, events: dict[str, param.parameterized.Event], msg: dict[str, Any],
         root: Model, model: Model, doc: Document, comm: Optional[Comm]
     ) -> None:
         if 'value_throttled' in msg:
@@ -288,7 +288,7 @@ class DateSlider(_SliderBase):
         'value': None, 'value_throttled': None, 'start': None, 'end': None
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkDateSlider
+    _widget_type: ClassVar[type[Model]] = _BkDateSlider
 
     def __init__(self, **params):
         if 'value' not in params:
@@ -353,11 +353,11 @@ class DiscreteSlider(CompositeWidget, _SliderBase):
 
     _supports_embed: ClassVar[bool] = True
 
-    _style_params: ClassVar[List[str]] = [
+    _style_params: ClassVar[list[str]] = [
         p for p in list(Layoutable.param) if p != 'name'
     ] + ['orientation']
 
-    _slider_style_params: ClassVar[List[str]] = [
+    _slider_style_params: ClassVar[list[str]] = [
         'bar_color', 'direction', 'disabled', 'orientation'
     ]
 
@@ -610,7 +610,7 @@ class RangeSlider(_RangeSliderBase):
 
     _rename: ClassVar[Mapping[str, str | None]] = {'name': 'title', 'value_start': None, 'value_end': None, 'value_throttled': None}
 
-    _widget_type: ClassVar[Type[Model]] = _BkRangeSlider
+    _widget_type: ClassVar[type[Model]] = _BkRangeSlider
 
     def __init__(self, **params):
         super().__init__(**params)
@@ -710,7 +710,7 @@ class DateRangeSlider(_SliderBase):
         'value_throttled': None
     }
 
-    _widget_type: ClassVar[Type[Model]] = _BkDateRangeSlider
+    _widget_type: ClassVar[type[Model]] = _BkDateRangeSlider
 
     _property_conversion = staticmethod(value_as_date)
 
@@ -816,9 +816,9 @@ class _EditableContinuousSlider(CompositeWidget):
     show_value = param.Boolean(default=False, readonly=True, precedence=-1, doc="""
         Whether to show the widget value.""")
 
-    _composite_type: ClassVar[Type[Panel]] = Column
-    _slider_widget: ClassVar[Type[Widget]]
-    _input_widget: ClassVar[Type[Widget]]
+    _composite_type: ClassVar[type[Panel]] = Column
+    _slider_widget: ClassVar[type[Widget]]
+    _input_widget: ClassVar[type[Widget]]
     __abstract = True
 
     def __init__(self, **params):
@@ -979,8 +979,8 @@ class EditableFloatSlider(_EditableContinuousSlider, FloatSlider):
     fixed_end = param.Number(default=None, doc="""
         A fixed upper bound for the slider and input.""")
 
-    _slider_widget: ClassVar[Type[Widget]] = FloatSlider
-    _input_widget: ClassVar[Type[Widget]] = FloatInput
+    _slider_widget: ClassVar[type[Widget]] = FloatSlider
+    _input_widget: ClassVar[type[Widget]] = FloatInput
 
 
 class EditableIntSlider(_EditableContinuousSlider, IntSlider):
@@ -1004,8 +1004,8 @@ class EditableIntSlider(_EditableContinuousSlider, IntSlider):
     fixed_end = param.Integer(default=None, doc="""
        A fixed upper bound for the slider and input.""")
 
-    _slider_widget: ClassVar[Type[Widget]] = IntSlider
-    _input_widget: ClassVar[Type[Widget]] = IntInput
+    _slider_widget: ClassVar[type[Widget]] = IntSlider
+    _input_widget: ClassVar[type[Widget]] = IntInput
 
 
 class EditableRangeSlider(CompositeWidget, _SliderBase):
@@ -1050,7 +1050,7 @@ class EditableRangeSlider(CompositeWidget, _SliderBase):
     show_value = param.Boolean(default=False, readonly=True, precedence=-1, doc="""
         Whether to show the widget value.""")
 
-    _composite_type: ClassVar[Type[Panel]] = Column
+    _composite_type: ClassVar[type[Panel]] = Column
 
     def __init__(self, **params):
         if 'width' not in params and 'sizing_mode' not in params:
